//------------------------------------------------------------------------
// File name...............: PrintReport.h
// Library.................: Microsoft Foundation Classes
// Beskrivelse.............:				   
//		Headerdefinition af egne Report-klasser
//
//------------------------------------------------------------------------
#ifndef	__PrintReport_h__
#define	__PrintReport_h__ 

#include "ObjKlasseModel.h"	// Declaration af egne "forretnings"-klasser

#include <assert.h>			// til fejlcheck

//------------------------------------------------------------------------
//	Basis Report-interface	-   styrer print sammen med klasserne
//								CWindowsDoc og CWindowsView 
//------------------------------------------------------------------------
class CxReport
{
public:
	CxReport	(void); 
	CxReport	(CString MyReportName, long MyMaxLinesPerPage);
	~CxReport	(void);
	virtual	void	DeleteReport();		// kaldes for at nedlgge objekt

	// funktioner til kommunikation med brugergrnseflade
	virtual	void	SetReportID(long	NyID);			// kaldes af Report-handler
	virtual	long	GetReportID(void);					// kaldes af Report-handler
	virtual	CString	GetReportName(void);				// kaldes for identifikation fra grnseflade
	virtual	long	GetMaxLinesPerPage(void);			// kaldes fr start fra grnseflade
	virtual	void	SetLinesPerPage(long NewLinesPerPage);// kaldes ved start fra grnseflade
														// med sidestrrelse
	virtual	void	BeginOfPrintReport(void);			// kaldes ved start fra grnseflade
	virtual	void	BeginOfViewReport(void);			// kaldes ved start fra grnseflade
	virtual	CString	GetLine(void);						// kaldes af grnseflade for hver linie
	virtual	BOOL	EndOfReport(void);					// Skal returnere sand nr der ikke er
														// flere linier
protected:
	long	MaxLinesPerPage;
	long	LinesPerPage;
	CString ReportName;
	long	ReportID;
};
//------------------------------------------------------------------------
//	ReportHandler klasse   -   styrer print sammen med klasserne
//								CWindowsDoc og CWindowsView 
//------------------------------------------------------------------------

class CxReportHandler
{
public:
	CxReportHandler		(void);
	~CxReportHandler	(void);
	virtual	void		AddReport(CxReport*	pNewReport);
	virtual	void		RemoveReport(CxReport* pValgReport);
	virtual	CxReport*	GetFirstReport(void);
	virtual	CxReport*	GetNextReport(void);
private:
    CxReport* pReport[20];
	int		MaxReport;
	int		AktReport;
	long	LastReportID;
};

extern CxReportHandler ReportHandler;

//-----------------------------------------------------------
//  Printer objekt som bruger kan anvende
//-----------------------------------------------------------

class CxPrint : public CxReport
{
public:
	CxPrint		(void);
	~CxPrint	(void);
	virtual	void	DeleteReport();		// kaldes for at nedlgge objekt

	//-------------------------------------------------------------
	// anvendelses printer funktioner
	// klasse skal oprettes af CxReportHandler
	virtual	void	OpenPrint(CString MyReportName, long MyMaxLinesPerPage);
	virtual	void	ClosePrint(void);
	virtual	void	PrintLine(CString TextLine);
	//-------------------------------------------------------------
	
	
	// funktioner til kommunikation med brugergrnseflade
	virtual	void	BeginOfPrintReport(void);			// kaldes ved start fra grnseflade
	virtual	CString	GetLine(void);
	virtual	BOOL	EndOfReport(void);

private:
    CStringArray TextLines;
	long	PrintLineNr;
	BOOL	PrintIsOpen;
	BOOL	PrintIsClosed;
};



#endif		// slut p header - sikre mod flere includes
